(* Guestfs Browser.
 * Copyright (C) 2010 Red Hat Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *)

(** The Window module handles all aspects of the main window, menus,
    dialogs and so on. *)

type window_state

val open_main_window : unit -> window_state
  (** Open the main Gtk window, set up the menus, callbacks and so on. *)

val failure : window_state -> exn -> unit
  (** This is the global error handling function.  It is invoked in
      the main thread for failures in the slave thread (see
      {!Slave.set_failure_hook}). *)

val throbber_busy : window_state -> unit -> unit
val throbber_idle : window_state -> unit -> unit
  (** These are callbacks from the slave thread (invoked in the main
      thread) which are called whenever the throbber should be
      animated/busy or idle.  *)

val set_statusbar : window_state -> string -> unit
  (** This callback from the slave thread (invoked in the main thread)
      updates the status bar when some slave operation starts or
      stops. *)

val progress : window_state -> int64 * int64 -> unit
  (** This called whenever the progress bar should move. *)

val run_cli_request : window_state -> Cmdline.cli_request -> unit
  (** This function performs the {!Cmdline.cli_request} operation.
      The actual operation happens asynchronously after this function
      has returned. *)
